package vc.thinker.mqtt.forwardthinker;

import lombok.extern.slf4j.Slf4j;
import org.springframework.boot.autoconfigure.condition.ConditionalOnBean;
import org.springframework.stereotype.Component;
import vc.thinker.absctacts.mqtt.protocol.AbstractCommonBytesHandleMqttProtocol;
import vc.thinker.absctacts.mqtt.topic.TopicDefinition;
import vc.thinker.mqtt.config.ThinkerTestMqttConnectionProperties;
import vc.thinker.mqtt.forwardthinker.enums.FoxGatewayTopicDefinition;

/**
 * 富士康网关数据上报
 *
 * @author HeTongHao
 * @since 2022-06-28 16:00
 */
@Slf4j
@Component
@ConditionalOnBean(ThinkerTestMqttConnectionProperties.class)
public class ThinkerTestDataProtocol extends AbstractCommonBytesHandleMqttProtocol {
    public ThinkerTestDataProtocol(ThinkerTestMqttConnectionProperties mqttConnectionProperties) {
        super(mqttConnectionProperties);
    }

    @Override
    public String[] subscribe() {
        return new String[]{
                FoxGatewayTopicDefinition.report.getTopic(),
                FoxGatewayTopicDefinition.report_version.getTopic(),
        };
    }

    @Override
    protected TopicDefinition resolveByTopic(String topic) {
        String protocolCode = FoxGatewayTopicDefinition.resolveProtocolCodeByTopic(topic);
        String matchTopic = topic.replace(protocolCode, "+");
        return FoxGatewayTopicDefinition.RESOLVE_BY_TOPIC.resolve(matchTopic);
    }
}
