package vc.thinker.mqtt.forwardthinker.actor.up;

import akka.actor.AbstractActor;
import akka.japi.pf.ReceiveBuilder;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.config.ConfigurableBeanFactory;
import org.springframework.context.annotation.Scope;
import org.springframework.stereotype.Component;
import vc.thinker.absctacts.mqtt.entity.MqttResponseBytes;
import vc.thinker.mqtt.forwardthinker.ThinkerProdProtocolClient;
import vc.thinker.mqtt.forwardthinker.enums.FoxGatewayTopicDefinition;

import javax.annotation.Resource;
import java.util.List;

/**
 * 网关上报数据接收
 *
 * @author HeTongHao
 * @since 2022/6/28 14:10
 */
@Slf4j
@Component
@Scope(ConfigurableBeanFactory.SCOPE_PROTOTYPE)
public class ThirdPartyReportDataActor extends AbstractActor {

    @Resource
    private ThinkerProdProtocolClient thinkerProdProtocolClient;

    /**
     * 转发的网关编号列表
     */
    private static final List<String> PROTOCOL_CODES = List.of("CRRC_SMART_COCKPIT_SYSTEM", "WF_IOT_FUSE_SYSTEM");

    public ThirdPartyReportDataActor() {
        receive(ReceiveBuilder.match(MqttResponseBytes.class, mqttResponse -> {
            String protocolCode = FoxGatewayTopicDefinition.resolveProtocolCodeByTopic(mqttResponse.getTopic());
            // 指转发指定协议下的设备
            if (PROTOCOL_CODES.contains(protocolCode)) {
                thinkerProdProtocolClient.getMqttCommandPush()
                        .sendMqttMessage(mqttResponse.getTopic(), mqttResponse.getMessage());
            }
        }).build());
    }
}
